@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2012-2023 Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2012-2024 Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -361,6 +361,8 @@ char ac_osn_username[MAX_STR_LEN], ac_osn_password[MAX_STR_LEN];
 char ac_osn_minutes_str[EQSO_LEN];
 char ac_filename[MAX_STR_LEN], new_ac_filename[MAX_STR_LEN];
 char ac_adsbone_minutes_str[EQSO_LEN];
+char ac_dump1090_url[MAX_STR_LEN];
+
 char ac_centerwwl[EQSO_LEN];
 char ac_kfactor_str[DBL_LEN];
 char ac_arwidth_str[DBL_LEN];   
@@ -405,6 +407,7 @@ void refresh_ac_opts(void *arg){
     STORE_SINT(cfg, ac_adsbone_minutes);
     STORE_STR(cfg, ac_filename);
     z_unix(cfg->ac_filename);
+    STORE_STR(cfg, ac_dump1090_url);
     STORE_STR(cfg, ac_centerwwl);
     STORE_SDBL(cfg, ac_kfactor);
     STORE_SDBL(cfg, ac_arwidth);
@@ -440,6 +443,7 @@ void menu_ac_opts(void *arg){
     LOAD_SINT(cfg, ac_adsbone_minutes);
     g_snprintf(ac_filename, MAX_STR_LEN, "%s", cfg->ac_filename);
     z_wokna(ac_filename);
+    LOAD_STR(cfg, ac_dump1090_url);
     LOAD_STR(cfg, ac_centerwwl);
     g_snprintf(ac_kfactor_str, DBL_LEN, "%3.3f", cfg->ac_kfactor);
     g_snprintf(ac_arwidth_str, DBL_LEN, "%3.1f", cfg->ac_arwidth);
@@ -544,7 +548,22 @@ void menu_ac_opts(void *arg){
     d->items[i].msg = TRANSLATE("Interval [minutes]");
     d->items[i].wrap = 1;
 
-//////////////////////////////////////////////////////
+    /////////////////////////////////////////////////////////////
+    d->items[++i].type = D_CHECKBOX;
+    d->items[i].gid = 1;
+    d->items[i].gnum = AC_DUMP1090;
+    d->items[i].dlen = sizeof(int);
+    d->items[i].data = (char*)&ac_provider;
+    d->items[i].msg = "dump1090";
+
+    d->items[++i].type = D_FIELD;
+    d->items[i].dlen = MAX_STR_LEN;
+    d->items[i].data = ac_dump1090_url;
+    d->items[i].maxl = 60;
+    d->items[i].msg = TRANSLATE("URL");
+    d->items[i].wrap = 1;
+    
+    //////////////////////////////////////////////////////
     d->items[i].wrap++;
     d->items[++i].type = D_FIELD;
     d->items[i].dlen = EQSO_LEN;
